package com.ruoyi.project.zjsgfa.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.project.zjsgfa.domain.SjJsjg;
import com.ruoyi.project.zjsgfa.domain.SjJsjgt;

/**
 * 设计信息-井身结构Service接口
 * 
 * @author ruoyi
 * @date 2025-06-24
 */
public interface ISjJsjgService 
{
    /**
     * 查询设计信息-井身结构
     * 
     * @param id 设计信息-井身结构主键
     * @return 设计信息-井身结构
     */
    public SjJsjg selectSjJsjgById(Long id);

    /**
     * 查询设计信息-井身结构列表
     * 
     * @param sjJsjg 设计信息-井身结构
     * @return 设计信息-井身结构集合
     */
    public List<SjJsjg> selectSjJsjgList(SjJsjg sjJsjg);

    /**
     * 新增设计信息-井身结构
     * 
     * @param sjJsjg 设计信息-井身结构
     * @return 结果
     */
    public int insertSjJsjg(SjJsjg sjJsjg);

    /**
     * 修改设计信息-井身结构
     * 
     * @param sjJsjg 设计信息-井身结构
     * @return 结果
     */
    public int updateSjJsjg(SjJsjg sjJsjg);

    /**
     * 批量删除设计信息-井身结构
     * 
     * @param ids 需要删除的设计信息-井身结构主键集合
     * @return 结果
     */
    public int deleteSjJsjgByIds(Long[] ids);

    /**
     * 删除设计信息-井身结构信息
     * 
     * @param id 设计信息-井身结构主键
     * @return 结果
     */
    public int deleteSjJsjgById(Long id);

    Map selectJsjgt(SjJsjg sjJsjg);

    int savaJsjgt(SjJsjgt sjJsjg);


}
